@@ -1,17 +1,18 @@
-"as.traj" <-
-function(id, xy, date, burst=id, ...)
-  {
+"as.traj" <- function(id, xy, date, burst=id, ...)
+{
+    ## Verifications
     if (!is.data.frame(xy))
-      stop("xy should be a data.frame")
+        stop("xy should be a data.frame")
     if (ncol(xy)!=2)
-      stop("xy should have two columns")
+        stop("xy should have two columns")
     if (!inherits(date, "POSIXct"))
-      stop("date should be of class \"POSIXct\"")
+        stop("date should be of class \"POSIXct\"")
     id <- factor(id)
     burst <- factor(burst)
     if (!all(apply(table(id,burst)>0,2,sum)==1))
-      stop("one burst level should belong to only one id level")
+        stop("one burst level should belong to only one id level")
 
+    ## Bases
     names(xy)<-c("x", "y")
     bas<-data.frame(id=id,
                     xy, date=date, burst=burst, ...)
@@ -20,20 +21,22 @@ function(id, xy, date, burst=id, ...)
     nl <- unlist(lapply(li, nrow)) > 1
     li <- li[nl]
     if (any(!nl))
-      warning(paste("At least two relocations are needed for a burst:\n",
-                    sum(!nl), "circuits have been deleted"))
+        warning(paste("At least two relocations are needed for a burst:\n",
+                      sum(!nl), "circuits have been deleted"))
     li<-lapply(li, foo)
 
-    ## Vrification que pas de doublons au niveau des dates
+
+    ## Verification that no double dates
     foob<-function(x) {
-      ind<-rep(0,nrow(x))
-      for (i in 2:nrow(x)) {
-        if ((as.numeric(x$date))[i]==(as.numeric(x$date))[i-1])
-          ind[i]<-1
-      }
-      return(x[ind==0,])
+        ind<-rep(0,nrow(x))
+        for (i in 2:nrow(x)) {
+            if ((as.numeric(x$date))[i]==(as.numeric(x$date))[i-1])
+                ind[i]<-1
+        }
+        return(x[ind==0,])
     }
 
+    ## output
     li<-lapply(li, foob)
     bas<-do.call("rbind", li)
     row.names(bas)<-as.character(1:nrow(bas))
@@ -41,5 +44,5 @@ function(id, xy, date, burst=id, ...)
     bas$burst <- factor(bas$burst)
     class(bas)<-c("traj", "data.frame")
     return(bas)
-  }
+}
 
