@@ -1,11 +1,16 @@
-"kernelbb" <-
-function(tr, sig1, sig2, grid = 40, same4all=FALSE, byburst=FALSE)
-  {
+"kernelbb" <- function(tr, sig1, sig2, grid = 40,
+                       same4all=FALSE, byburst=FALSE)
+{
+    ## verifications
     x <- ltraj2traj(tr)
     if (!inherits(x, "traj"))
-      stop("tr should be of class \"ltraj\"")
+        stop("tr should be of class \"ltraj\"")
+
+    ## Bases
     sorties <- list()
     gr <- grid
+    x <- x[!is.na(x$x),]
+    x <- x[!is.na(x$y),]
     xy<-x[,c("x","y")]
     sig12<-sig1^2
     sig22<-sig2^2
@@ -16,16 +21,16 @@ function(tr, sig1, sig2, grid = 40, same4all=FALSE, byburst=FALSE)
       fac<-x$id
     fac<-factor(fac)
     lixy<-split(x,fac)
-    
+
     if (same4all) {
       if (length(as.vector(gr)) == 1) {
-        if (!is.numeric(gr)) 
+        if (!is.numeric(gr))
           stop("grid should be an object of class asc or a number")
         xli <- range(xy[, 1])
         yli <- range(xy[, 2])
-        xli <- c(xli[1] - 0.3 * abs(xli[2] - xli[1]), xli[2] + 
+        xli <- c(xli[1] - 0.3 * abs(xli[2] - xli[1]), xli[2] +
                  0.3 * abs(xli[2] - xli[1]))
-        yli <- c(yli[1] - 0.3 * abs(yli[2] - yli[1]), yli[2] + 
+        yli <- c(yli[1] - 0.3 * abs(yli[2] - yli[1]), yli[2] +
                  0.3 * abs(yli[2] - yli[1]))
         xygg <- data.frame(x = xli, y = yli)
         grid <- ascgen(xygg, nrcol = grid)
@@ -33,7 +38,7 @@ function(tr, sig1, sig2, grid = 40, same4all=FALSE, byburst=FALSE)
         lx <- nrow(grid) * cellsize
         ly <- ncol(grid) * cellsize
         ref <- lx
-        if (ly > lx) 
+        if (ly > lx)
           ref <- ly
         xll <- attr(grid, "xll")
         yll <- attr(grid, "yll")
@@ -57,7 +62,7 @@ function(tr, sig1, sig2, grid = 40, same4all=FALSE, byburst=FALSE)
       dft<-lixy[[i]]
       df<-dft[,c("x","y")]
       if (length(as.vector(gr)) == 1) {
-        if (!is.numeric(gr)) 
+        if (!is.numeric(gr))
           stop("grid should be an object of class asc or a number")
         if (!same4all) {
           grid <- matrix(0, ncol = gr, nrow = gr)
@@ -66,7 +71,7 @@ function(tr, sig1, sig2, grid = 40, same4all=FALSE, byburst=FALSE)
           lx <- rgx[2] - rgx[1]
           ly <- rgy[2] - rgy[1]
           ref <- lx
-          if (ly > lx) 
+          if (ly > lx)
             ref <- ly
           xll <- rgx[1]
           yll <- rgy[1]
@@ -86,12 +91,12 @@ function(tr, sig1, sig2, grid = 40, same4all=FALSE, byburst=FALSE)
           class(grid) <- "asc"
         }
       }
-      
+
       xyg<-getXYcoords(grid)
       date<-as.double(dft$date)-min(as.double(dft$date))
       toto<-.C("kernelbb", as.double(t(grid)), as.double(xyg$x),
                as.double(xyg$y), as.integer(ncol(grid)),as.integer(nrow(grid)),
-               as.integer(nrow(x)), as.double(sig12), as.double (sig22), 
+               as.integer(nrow(x)), as.double(sig12), as.double (sig22),
                as.double(df$x), as.double(df$y), as.double(date),
                PACKAGE="adehabitat")
       UD <- matrix(toto[[1]], nrow = nrow(grid), byrow = TRUE)
